<?php
// Get helper instance for web forms. This will add the opening form-tag to
// the helper's render cache which is simply a small variable in the class
// BaseHelper.
$helperInstance = ObjectFactory::createObjectByConfiguredName('html_form_helper_class', array($this, 'shipsimu_user_login'));

// Is the form enabled?
if ($helperInstance->ifLoginIsEnabled()) {
	// Form is active
	$helperInstance->addFormGroup('login', "Gebe hier deine Logindaten ein:");

	// Which login method has been configured?
	if ($helperInstance->ifLoginWithUsername()) {
		// Login with user name only
		$helperInstance->addFormSubGroup('username', "Bitte mit deinem Nickname einloggen.");
		$helperInstance->addFieldText('username', "Dein Nickname:");
		$helperInstance->addInputTextField('username');
	} elseif ($helperInstance->ifLoginWithEmail()) {
		// Login with email address only
		$helperInstance->addFormSubGroup('email', "Bitte mit deiner Email-Adresse einloggen.");
		$helperInstance->addFieldText('email', "Deine Email-Addresse:");
		$helperInstance->addInputTextField('email');
	} else {
		// Login with email address or user name
		$helperInstance->addFormSubGroup('user_email', "Bitte mit deinem Nickname oder Email-Adresse einloggen.");
		$helperInstance->addFieldText('user_email', "Dein Nickname/Email:");
		$helperInstance->addInputTextField('user_email');
	}

	// Add password input field
	$helperInstance->addFormSubGroup('pass', "Gebe dein Passwort von der Anmeldung ein.");
	$helperInstance->addFieldText('pass', "Dein Passwort:");
	$helperInstance->addInputPasswordField('pass');

	// CAPTCHA enabled?
	if ($helperInstance->ifFormSecuredWithCaptcha()) {
		$helperInstance->addFormGroup('captcha_user', "Das Benutzer-Login ist durch ein CAPTCHA gesch&uuml;tzt. Bitte wiederhole den angezeigten Code, damit du dich einloggen kannst.");
		$helperInstance->addCaptcha();
	} // END - if

	// Submit buttons
	$helperInstance->addFormGroup('buttons_user', "Alles richtig eingegeben?");
	$helperInstance->addInputResetButton("Formular leeren");
	$helperInstance->addInputSubmitButton("Zum Spiel einloggen");
} else {
	// Form is inactive
	$helperInstance->addFormNote('form_deactivated', "Einloggen in&#39;s Spiel ist derzeit administrativ deaktiviert worden. Bitte komme sp&auml;ter noch mal wieder.");
	$helperInstance->addFormNote('admin_notice', "Nachricht vom Admin: <span id=\"disabled_reason\">".$this->getConfigInstance()->readConfig('login_disabled_reason')."</span>");
}

// Formular schliessen
$helperInstance->flushContent();

// Ist Gastlogin erlaubt?
if ($helperInstance->ifGuestLoginAllowed()) {
	// Neue Helper-Instanz holen
	$helperInstance = ObjectFactory::createObjectByConfiguredName('html_form_helper_class', array($this, 'shipsimu_guest_login'));
	$helperInstance->addInputHiddenConfiguredField('user', 'guest_login');
	$helperInstance->addInputHiddenConfiguredField('passwd', 'guest_login');

	// CAPTCHA enbaled?
	if ($helperInstance->ifFormSecuredWithCaptcha()) {
		$helperInstance->addFormGroup('captcha_guest', "Unser Gast-Login ist durch ein CAPTCHA gesch&uuml;tzt. Bitte wiederhole den angezeigten Code, damit du dich einloggen kannst.");
		$helperInstance->addCaptcha();
	} // END - if

	// Submit button
	$helperInstance->addFormGroup('buttons_guest', "Gastlogins sind in der Funkionsweise eingeschr&auml;nkt. Mehr dazu unter &quot;Gastlogin&quot;.");
	$helperInstance->addInputSubmitButton("Als Gast einloggen");
	$helperInstance->flushContent();
}

// Get helper instance
$helperInstance = ObjectFactory::createObjectByConfiguredName('html_link_helper_class', array($this, 'register'));

// Set link text
$helperInstance->addLinkWithTextById('register_login');

// Flush the content
$helperInstance->flushContent();

// [EOC]
?>
<div id="content_header">
	Einloggen zu <span class="app_name">{?app_full_name?}</span>
</div>

<div id="content_body">
	<div id="login_box">
		{?shipsimu_user_login?}
	</div>

	<div id="guest_login">
		{?shipsimu_guest_login?}
	</div>
</div>

<div id="content_footer">
	Noch kein Spieleaccount? {?register?}
</div>
